#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
# 2022-11-30: fixed CheckParameterRulespecWithoutItem (from CheckParameterRulespecWithItem)

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    DropdownChoice,
    MonitoringState,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_mgmt():
    return Dictionary(
        title=_('Check Point Management Server'),
        elements=[
            ('desired_mode',
             DropdownChoice(
                 title=_('Select Mgmt server desired mode'),
                 choices=[
                     ('active', _('active')),
                     ('standby', _('standby')),
                 ])),
            ('state_if_not_desired',
             MonitoringState(
                 default_value=1,
                 title=_('State if Mgmt server not in desired mode.'),
             )),

            ('state_islicenseviolation',
             MonitoringState(
                 default_value=1,
                 title=_('State on license violation.'),
             )),

            ('state_not_fwmisalive',
             MonitoringState(
                 default_value=2,
                 title=_('State if "fwm" daemon not alive.'),
             )),

            ('state_statcode',
             MonitoringState(
                 default_value=2,
                 title=_('State if status is not OK.'),
             )),

        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_mgmt',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_mgmt,
        title=lambda: _('Check Point Management Server'),
    ))
